Module: FlowChat
- Defined in:
- lib/flow_chat/telegram.rb,
lib/flow_chat.rb,
lib/flow_chat/app.rb,
lib/flow_chat/flow.rb,
lib/flow_chat/input.rb,
lib/flow_chat/media.rb,
lib/flow_chat/config.rb,
lib/flow_chat/prompt.rb,
lib/flow_chat/context.rb,
lib/flow_chat/factory.rb,
lib/flow_chat/version.rb,
lib/flow_chat/executor.rb,
lib/flow_chat/security.rb,
lib/flow_chat/async_job.rb,
lib/flow_chat/interrupt.rb,
lib/flow_chat/processor.rb,
lib/flow_chat/choice_titles.rb,
lib/flow_chat/http/renderer.rb,
lib/flow_chat/ussd/renderer.rb,
lib/flow_chat/delivery_error.rb,
lib/flow_chat/meta/challenge.rb,
lib/flow_chat/meta/signature.rb,
lib/flow_chat/text_truncator.rb,
lib/flow_chat/instrumentation.rb,
lib/flow_chat/intercom/client.rb,
lib/flow_chat/telegram/client.rb,
lib/flow_chat/whatsapp/client.rb,
lib/flow_chat/instagram/client.rb,
lib/flow_chat/messenger/client.rb,
lib/flow_chat/generic_async_job.rb,
lib/flow_chat/intercom/renderer.rb,
lib/flow_chat/phone_number_util.rb,
lib/flow_chat/telegram/renderer.rb,
lib/flow_chat/ussd/gateway/nalo.rb,
lib/flow_chat/whatsapp/renderer.rb,
lib/flow_chat/instagram/renderer.rb,
lib/flow_chat/messenger/renderer.rb,
lib/flow_chat/meta/choice_ladder.rb,
lib/flow_chat/session/middleware.rb,
lib/flow_chat/http/gateway/simple.rb,
lib/flow_chat/named_configuration.rb,
lib/flow_chat/simulator/controller.rb,
lib/flow_chat/gateway_async_support.rb,
lib/flow_chat/instrumentation/setup.rb,
lib/flow_chat/meta/gateway_identity.rb,
lib/flow_chat/intercom/configuration.rb,
lib/flow_chat/meta/messaging_gateway.rb,
lib/flow_chat/telegram/configuration.rb,
lib/flow_chat/whatsapp/configuration.rb,
lib/flow_chat/instagram/configuration.rb,
lib/flow_chat/messenger/configuration.rb,
lib/flow_chat/http/configuration_error.rb,
lib/flow_chat/meta/configuration_error.rb,
lib/flow_chat/telegram/gateway/bot_api.rb,
lib/flow_chat/meta/signature_validation.rb,
lib/flow_chat/meta/webhook_verification.rb,
lib/flow_chat/whatsapp/template_manager.rb,
lib/flow_chat/instagram/gateway/send_api.rb,
lib/flow_chat/messenger/gateway/send_api.rb,
lib/flow_chat/renderers/markdown_support.rb,
lib/flow_chat/ussd/middleware/pagination.rb,
lib/flow_chat/whatsapp/gateway/cloud_api.rb,
lib/flow_chat/session/cache_session_store.rb,
lib/flow_chat/intercom/configuration_error.rb,
lib/flow_chat/telegram/configuration_error.rb,
lib/flow_chat/whatsapp/configuration_error.rb,
lib/flow_chat/http/middleware/choice_mapper.rb,
lib/flow_chat/instagram/configuration_error.rb,
lib/flow_chat/intercom/gateway/intercom_api.rb,
lib/flow_chat/messenger/configuration_error.rb,
lib/flow_chat/ussd/middleware/choice_mapper.rb,
lib/flow_chat/instrumentation/log_subscriber.rb,
lib/flow_chat/instrumentation/metrics_collector.rb,
lib/flow_chat/intercom/middleware/choice_mapper.rb,
lib/flow_chat/telegram/middleware/choice_mapper.rb,
lib/flow_chat/whatsapp/middleware/choice_mapper.rb,
lib/flow_chat/instagram/middleware/choice_mapper.rb,
lib/flow_chat/messenger/middleware/choice_mapper.rb
Overview
Telegram integration for FlowChat All files are autoloaded by Zeitwerk based on file path conventions
Defined Under Namespace
Modules: ChoiceTitles, Config, GatewayAsyncSupport, Http, Instagram, Instrumentation, Intercom, Interrupt, Messenger, Meta, NamedConfiguration, PhoneNumberUtil, Renderers, Security, Session, Simulator, Telegram, TextTruncator, Ussd, Whatsapp Classes: App, AsyncJob, BackgroundController, BackgroundRequest, BackgroundRequestBody, Context, DeliveryError, Executor, Factory, Flow, GenericAsyncJob, Input, Media, Processor, Prompt
Constant Summary collapse
- VERSION =
"0.10.1"
Class Method Summary collapse
-
.instrument(event_name, payload = {}, &block) ⇒ Object
Access to instrumentation.
-
.logger ⇒ Object
Shorthand for accessing the logger throughout the application.
- .metrics ⇒ Object
- .root ⇒ Object
- .setup_instrumentation! ⇒ Object
Class Method Details
.instrument(event_name, payload = {}, &block) ⇒ Object
Access to instrumentation
22 23 24 |
# File 'lib/flow_chat.rb', line 22 def self.instrument(event_name, payload = {}, &block) FlowChat::Instrumentation.instrument(event_name, payload, &block) end |
.logger ⇒ Object
Shorthand for accessing the logger throughout the application
212 213 214 |
# File 'lib/flow_chat/config.rb', line 212 def self.logger Config.logger end |
.metrics ⇒ Object
26 27 28 |
# File 'lib/flow_chat.rb', line 26 def self.metrics FlowChat::Instrumentation::Setup.metrics_collector end |
.root ⇒ Object
13 14 15 |
# File 'lib/flow_chat.rb', line 13 def self.root Pathname.new __dir__ end |
.setup_instrumentation! ⇒ Object
17 18 19 |
# File 'lib/flow_chat.rb', line 17 def self.setup_instrumentation! FlowChat::Instrumentation::Setup.setup_instrumentation! end |